==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEQUALIFICATIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour EMPLOYEEQUALIFICATIONS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEQUALIFICATIONS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPATCHEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECREWID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEPICTURE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISDEPTVALID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REMAININGAVAILABLEHRS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEQUALIFICATIONS_Type", propOrder = {
    "employeeid",
    "dispatchedhours",
    "qualificationid",
    "tradeid",
    "startdate",
    "enddate",
    "employeecrewid",
    "profilepicture",
    "isdeptvalid",
    "remainingavailablehrs"
})
public class EMPLOYEEQUALIFICATIONS_Type {

    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;
    @XmlElement(name = "DISPATCHEDHOURS")
    protected QUANTITY dispatchedhours;
    @XmlElement(name = "QUALIFICATIONID")
    protected List<QUALIFICATIONID_Type> qualificationid;
    @XmlElement(name = "TRADEID")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "STARTDATE")
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE")
    protected DATETIME enddate;
    @XmlElement(name = "EMPLOYEECREWID")
    protected EMPLOYEECREWID_Type employeecrewid;
    @XmlElement(name = "PROFILEPICTURE")
    protected DOCUMENTID_Type profilepicture;
    @XmlElement(name = "ISDEPTVALID")
    protected String isdeptvalid;
    @XmlElement(name = "REMAININGAVAILABLEHRS")
    protected QUANTITY remainingavailablehrs;

    /**
     * Obtient la valeur de la propriété employeeid.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Définit la valeur de la propriété employeeid.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

    /**
     * Obtient la valeur de la propriété dispatchedhours.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDISPATCHEDHOURS() {
        return dispatchedhours;
    }

    /**
     * Définit la valeur de la propriété dispatchedhours.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDISPATCHEDHOURS(QUANTITY value) {
        this.dispatchedhours = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the qualificationid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getQUALIFICATIONID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QUALIFICATIONID_Type }
     * 
     * 
     */
    public List<QUALIFICATIONID_Type> getQUALIFICATIONID() {
        if (qualificationid == null) {
            qualificationid = new ArrayList<QUALIFICATIONID_Type>();
        }
        return this.qualificationid;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Obtient la valeur de la propriété enddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Définit la valeur de la propriété enddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

    /**
     * Obtient la valeur de la propriété employeecrewid.
     * 
     * @return
     *     possible object is
     *     {@link EMPLOYEECREWID_Type }
     *     
     */
    public EMPLOYEECREWID_Type getEMPLOYEECREWID() {
        return employeecrewid;
    }

    /**
     * Définit la valeur de la propriété employeecrewid.
     * 
     * @param value
     *     allowed object is
     *     {@link EMPLOYEECREWID_Type }
     *     
     */
    public void setEMPLOYEECREWID(EMPLOYEECREWID_Type value) {
        this.employeecrewid = value;
    }

    /**
     * Obtient la valeur de la propriété profilepicture.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getPROFILEPICTURE() {
        return profilepicture;
    }

    /**
     * Définit la valeur de la propriété profilepicture.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setPROFILEPICTURE(DOCUMENTID_Type value) {
        this.profilepicture = value;
    }

    /**
     * Obtient la valeur de la propriété isdeptvalid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISDEPTVALID() {
        return isdeptvalid;
    }

    /**
     * Définit la valeur de la propriété isdeptvalid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISDEPTVALID(String value) {
        this.isdeptvalid = value;
    }

    /**
     * Obtient la valeur de la propriété remainingavailablehrs.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREMAININGAVAILABLEHRS() {
        return remainingavailablehrs;
    }

    /**
     * Définit la valeur de la propriété remainingavailablehrs.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREMAININGAVAILABLEHRS(QUANTITY value) {
        this.remainingavailablehrs = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEQUALIFICATIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for EMPLOYEEQUALIFICATIONS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="EMPLOYEEQUALIFICATIONS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DISPATCHEDHOURS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID" maxOccurs="unbounded" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECREWID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROFILEPICTURE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISDEPTVALID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REMAININGAVAILABLEHRS" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEQUALIFICATIONS_Type", propOrder = {
    "employeeid",
    "dispatchedhours",
    "qualificationid",
    "tradeid",
    "startdate",
    "enddate",
    "employeecrewid",
    "profilepicture",
    "isdeptvalid",
    "remainingavailablehrs"
})
public class EMPLOYEEQUALIFICATIONS_Type {

    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;
    @XmlElement(name = "DISPATCHEDHOURS")
    protected QUANTITY dispatchedhours;
    @XmlElement(name = "QUALIFICATIONID")
    protected List<QUALIFICATIONID_Type> qualificationid;
    @XmlElement(name = "TRADEID")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "STARTDATE")
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE")
    protected DATETIME enddate;
    @XmlElement(name = "EMPLOYEECREWID")
    protected EMPLOYEECREWID_Type employeecrewid;
    @XmlElement(name = "PROFILEPICTURE")
    protected DOCUMENTID_Type profilepicture;
    @XmlElement(name = "ISDEPTVALID")
    protected String isdeptvalid;
    @XmlElement(name = "REMAININGAVAILABLEHRS")
    protected QUANTITY remainingavailablehrs;

    /**
     * Gets the value of the employeeid property.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Sets the value of the employeeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

    /**
     * Gets the value of the dispatchedhours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDISPATCHEDHOURS() {
        return dispatchedhours;
    }

    /**
     * Sets the value of the dispatchedhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDISPATCHEDHOURS(QUANTITY value) {
        this.dispatchedhours = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the qualificationid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getQUALIFICATIONID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QUALIFICATIONID_Type }
     * 
     * 
     * @return
     *     The value of the qualificationid property.
     */
    public List<QUALIFICATIONID_Type> getQUALIFICATIONID() {
        if (qualificationid == null) {
            qualificationid = new ArrayList<>();
        }
        return this.qualificationid;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Gets the value of the enddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Sets the value of the enddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

    /**
     * Gets the value of the employeecrewid property.
     * 
     * @return
     *     possible object is
     *     {@link EMPLOYEECREWID_Type }
     *     
     */
    public EMPLOYEECREWID_Type getEMPLOYEECREWID() {
        return employeecrewid;
    }

    /**
     * Sets the value of the employeecrewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EMPLOYEECREWID_Type }
     *     
     */
    public void setEMPLOYEECREWID(EMPLOYEECREWID_Type value) {
        this.employeecrewid = value;
    }

    /**
     * Gets the value of the profilepicture property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getPROFILEPICTURE() {
        return profilepicture;
    }

    /**
     * Sets the value of the profilepicture property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setPROFILEPICTURE(DOCUMENTID_Type value) {
        this.profilepicture = value;
    }

    /**
     * Gets the value of the isdeptvalid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISDEPTVALID() {
        return isdeptvalid;
    }

    /**
     * Sets the value of the isdeptvalid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISDEPTVALID(String value) {
        this.isdeptvalid = value;
    }

    /**
     * Gets the value of the remainingavailablehrs property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREMAININGAVAILABLEHRS() {
        return remainingavailablehrs;
    }

    /**
     * Sets the value of the remainingavailablehrs property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREMAININGAVAILABLEHRS(QUANTITY value) {
        this.remainingavailablehrs = value;
    }

}
